fluent_navigation library

Classes

CustomTransitionPage<T>
Page with custom transition functionality.
Fluent
The core facade of the Fluent ecosystem. Acts as a centralized Service Locator and Module Orchestrator.
FluentModule
GoRoute Get started Configuration Redirection Transition animations Named routes
A route that is displayed visually above the matching parent route using the Navigator.
GoRouterState
The route state during routing.
Interface defined to use the fluent navigation functionalities
Register and build all the fluent navigation dependencies
NoTransitionPage<T>
Custom transition page with no transition.
Registry
Defines the contract for dependency registration.
RouteBase
The base class for GoRoute and ShellRoute.
ShellRoute Configuration
A route that displays a UI shell around the matching child route.

Extensions

RegistryExtension on Registry

Properties

rootNavigatorKey GlobalKey<NavigatorState>
final