pop<T> abstract method
void
pop<T>([
- T? result
Pop the last route off the current screen And pass it an optional result.
Implementation
void pop<T>([T? result]);
Pop the last route off the current screen And pass it an optional result.
void pop<T>([T? result]);