NavigationApi class abstract
Interface defined to use the fluent navigation functionalities
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Get the navigator key
no setter
-
router
→ RouterConfig<
Object> -
Get the router configuration
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canPop(
) → bool - Checks if the current route can be popped.
- Navigate to a named route with optional parameters, query parameters and an extra object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void - Pop the last route off the current screen And pass it an optional result.
-
pushTo<
T> (String routeName, {Map< String, String> params = const <String, String>{}, Map<String, dynamic> queryParams = const <String, dynamic>{}, Object? extra}) → Future<T?> - Push a named route onto the page stack with optional parameters, query parameters and an extra object
-
replaceWith(
String routeName, {Map< String, String> params = const <String, String>{}, Map<String, dynamic> queryParams = const <String, dynamic>{}, Object? extra}) → Future<void> - Replace the current route with a named route with optional parameters, query parameters and an extra object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited